pub struct CatSoundVariant {
pub key: Identifier,
pub adult_sounds: CatAge,
pub baby_sounds: CatAge,
}Expand description
Represents a set of sounds for a cat variant from a data pack JSON file.
Fields
key: Identifieradult_sounds: CatAgebaby_sounds: CatAgeTrait Implementations
Sourceimpl Debug for CatSoundVariant
impl Debug for CatSoundVariant
impl Eq for CatSoundVariant
Sourceimpl PartialEq for CatSoundVariant
impl PartialEq for CatSoundVariant
Sourceimpl RegistryEntry for CatSoundVariant
impl RegistryEntry for CatSoundVariant
Sourceimpl RegistryReferenceEntry for CatSoundVariant
impl RegistryReferenceEntry for CatSoundVariant
Sourceconst REGISTRY_NAME: &'static str = "cat sound variant"
const REGISTRY_NAME: &'static str = "cat sound variant"
Human-readable registry name used in codec errors.
Sourcefn reference_by_id(id: usize) -> Option<&'static Self>
fn reference_by_id(id: usize) -> Option<&'static Self>
Looks up an entry by its protocol registry ID.
Sourcefn reference_by_key(key: &Identifier) -> Option<&'static Self>
fn reference_by_key(key: &Identifier) -> Option<&'static Self>
Looks up an entry by its registry key.
Sourceimpl ToNbtTag for &CatSoundVariant
impl ToNbtTag for &CatSoundVariant
fn to_nbt_tag(self) -> NbtTag
fn to_optional_nbt_tag(self) -> Option<NbtTag>